@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: StatisticsHandler.py 10149 2017-08-08 03:13:44Z David $
+# $Id: StatisticsHandler.py 10159 2017-08-08 11:28:27Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-08-08 11:13:44 +0800 (Tue, 08 Aug 2017) $
-# $Revision: 10149 $
+# $Date: 2017-08-08 19:28:27 +0800 (Tue, 08 Aug 2017) $
+# $Revision: 10159 $
 
 from datetime import timedelta, datetime
 
@@ -740,8 +740,6 @@ def getSubscriberHistory(requestGetData, conditions):
 
     @param slug Slug.
     """
-    from django.db import connection
-    connection.queries = []
 
     statusCode = conditions.pop('status', None)
 
